#ifndef POWERSAVE_DAEMONLIB_H
#define POWERSAVE_DAEMONLIB_H

#ifdef __cplusplus
extern "C" {
#endif

#include <unistd.h>
#include <stdio.h>

#define POWERSAVED_SOCKET_PATH "/var/run/powersave_socket"

int open_client_connection(void);
void close_client_connection(int sockfd);

int send_Action(int action);


	/***  Defined Actions/Requests accepted by the server *************/
	/* will be ignored, just for seeing if the server is running*/
#define POWERSAVED_ACTION_PING                  0x00000001
	/* request machine to go into standby*/
#define POWERSAVED_ACTION_STANDBY               0x00000002
	/* request machine to go into suspend*/
#define POWERSAVED_ACTION_SUSPEND               0x00000003

	/* this concerns cpufrequency scaling*/
	/* set to daemon to performance (alway max frequency)*/
#define POWERSAVED_ACTION_CPUFREQ_PERFORMANCE   0x00000004
	/* set to kernel powersave (always min frequency*/
#define POWERSAVED_ACTION_CPUFREQ_POWERSAVE     0x00000005
	/* this enables dynamic management of the powersave daemon*/
#define POWERSAVED_ACTION_CPUFREQ_DYNAMIC       0x00000006
	
	/* request current cpufreq mode*/
#define POWERSAVED_REQUEST_CPUFREQ_STATE_INFO   0x00000007
	/* request current battery state*/
#define POWERSAVED_REQUEST_BATTERY_STATE_INFO   0x00000008
	/* are we on AC or battery power? */
#define POWERSAVED_REQUEST_ON_POWER_INFO        0x00000009
#define POWERSAVED_REQUEST_REM_PERCENT_BATTERY  0x0000000a
#define POWERSAVED_REQUEST_REM_MINUTES_BATTERY  0x0000000b
#define POWERSAVED_REQUEST_BAT_CHARGING_STATE   0x0000000c
#define POWERSAVED_REQUEST_STANDBY_ALLOWED      0x0000000d
#define POWERSAVED_REQUEST_SUSPEND_ALLOWED      0x0000000e

	/*****************************************************************/
	
	/***  Defined Error/Return codes returned by the server ************/

#define POWERSAVED_NO_RIGHTS                   -0x00000002
#define POWERSAVED_ERROR                       -0x00000001
#define POWERSAVED_ERROR_NOERROR                0x00000001
#define POWERSAVED_ERROR_CPUFREQ_NOT_SUPPORTED  0x00000003
#define POWERSAVED_CPUFREQ_MODE_ALREADY_SET     0x00000004
	
	/* return codes for POWERSAVED_CPUFREQ_STATE_INFO*/
#define POWERSAVED_CPUFREQ_STATE_PERFORMANCE    0x00000005
#define POWERSAVED_CPUFREQ_STATE_POWERSAVE      0x00000006
#define POWERSAVED_CPUFREQ_STATE_DYNAMIC        0x00000007
	
	/* return codes for POWERSAVED_BATTERY_STATE_INFO*/
#define POWERSAVED_BATTERY_STATE_NORMAL         0x00000008
#define POWERSAVED_BATTERY_STATE_WARNING        0x00000009
#define POWERSAVED_BATTERY_STATE_LOW            0x0000000a
#define POWERSAVED_BATTERY_STATE_CRITICAL       0x0000000b
#define POWERSAVED_BATTERY_STATE_NO_BAT         0x00000015
	/* return codes for POWERSAVED_REQUEST_ON_POWER_INFO */
#define POWERSAVED_ON_AC_POWER                  0x0000000c
#define POWERSAVED_ON_BATTERY_POWER             0x0000000d
	/* return codes for POWERSAVED_REQUEST_BAT_CHARGIN_STATE */
#define POWERSAVED_BATTERY_CHARGING             0x0000000e
#define POWERSAVED_BATTERY_DISCHARGING          0x00000010
#define POWERSAVED_BATTERY_CHARG_DISCHARG       0x00000011
#define POWERSAVED_BATTERY_CHARG_UNKNOWN        0x00000012
	/* return codes for POWERSAVED_ACTION_STANDBY, 
	    POWERSAVED_ACTION_SUSPEND, POWERSAVED_REQUEST_STANDBY_ALLOWED and
	    POWERSAVED_REQUEST_SUSPEND_ALLOWED if disabled by configs*/
#define POWERSAVED_SUSPEND_DISABLED             0x00000013
#define POWERSAVED_STANDBY_DISABLED             0x00000014
	/*****************************************************************/


#ifdef __cplusplus
}
#endif

#endif
